/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.wicket.behavior;

import org.apache.wicket.behavior.IBehavior;
import org.wamblee.wicket.jquery.AbstractJQueryBehavior;

/**
 * Abstract tooltip behavior providing common options for tooltips.
 * 
 * @author Erik Brakkee
 */
public class AbstractTooltipBehavior extends AbstractJQueryBehavior {

    private String border;
    private String padding;
    private String background;

    public AbstractTooltipBehavior(String aFunction, IBehavior... aBehaviors) {
        super(aFunction, aBehaviors);
    }

    public AbstractTooltipBehavior border(String aValue) { 
        border = aValue;
        return this; 
    }

    public AbstractTooltipBehavior padding(String aValue) { 
        padding = aValue; 
        return this; 
    }

    public AbstractTooltipBehavior background(String aValue) { 
        background = aValue; 
        return this; 
    }

    @Override
    protected Object getConfigurationObject() {
        return this; 
    }

    public String getBorder() {
        return border;
    }

    public String getPadding() {
        return padding;
    }

    public String getBackground() {
        return background;
    }

}