/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.wicket.behavior;

import org.apache.wicket.behavior.HeaderContributor;
import org.apache.wicket.markup.html.JavascriptPackageResource;

/**
 * Tooltip behavior that adds tooltips based on the title attribute in an HTML
 * document. The behavior may be attached to pages or components and applies to
 * the element and its children to which it is applied.
 * 
 * @author Erik Brakkee
 * 
 */
public class ServerTooltipBehavior extends AbstractTooltipBehavior {

    private static final String READY_FUNCTION = "org.wamblee.tooltip.serverside";

    static final String SCRIPT = "wamblee-tooltip.js";

    private static HeaderContributor BEHAVIOR = JavascriptPackageResource
        .getHeaderContribution(ServerTooltipBehavior.class, SCRIPT);
    
    private String text; 

    /**
     * Constructs the tooltip.
     * @param aText Text to add.
     */
    public ServerTooltipBehavior(String aText) {
        super(READY_FUNCTION, new SupportBehavior(), BEHAVIOR);
        text = aText;
    }
    
    public String getText() {
        return text;
    }

}
